@@ -1,35 +1,51 @@
 #undef PACKAGE
 #undef VERSION
-#undef HAVE_LIBSM
+#undef GETTEXT_PACKAGE
+#undef GDM_USER_PATH
+#undef HALT_COMMAND
+#undef REBOOT_COMMAND
+#undef SUSPEND_COMMAND
+#undef ENABLE_IPV6
 #undef ENABLE_NLS
+#undef HAVE_ADT
 #undef HAVE_CATGETS
+#undef HAVE_CHPASS
+#undef HAVE_CLEARENV
+#undef HAVE_CRYPT
 #undef HAVE_DEFOPEN
 #undef HAVE_FBCONSOLE
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
-#undef HAVE_STPCPY
+#undef HAVE_LIBSM
+#undef HAVE_LIBXDMCP
+#undef HAVE_LOGINCAP
+#undef HAVE_LOGINDEVPERM
+#undef HAVE_LOGINRESTRICTIONS
 #undef HAVE_PAM
-#undef HAVE_TCPWRAPPERS
+#undef HAVE_PASSWDEXPIRED
+#undef HAVE_SCHED_YIELD
+#undef HAVE_SELINUX
+#undef HAVE_SETENV
+#undef HAVE_SETRESUID
 #undef HAVE_SHADOW
-#undef HAVE_CRYPT
+#undef HAVE_SOLARIS_XINERAMA
+#undef HAVE_STPCPY
+#undef HAVE_SYS_SOCKIO_H
+#undef HAVE_TCPWRAPPERS
+#undef HAVE_UNSETENV
 #undef HAVE_XINERAMA
 #undef HAVE_XFREE_XINERAMA
-#undef HAVE_SOLARIS_XINERAMA
-#undef HAVE_LIBXDMCP
-#undef HAVE_SETENV
-#undef HAVE_UNSETENV
-#undef HAVE_CLEARENV
-#undef HAVE_SETRESUID
+#undef HAVE_XINPUT
+#undef EXPANDED_AUTHDIR
 #undef EXPANDED_DATADIR
-#undef EXPANDED_PIXMAPDIR
 #undef EXPANDED_BINDIR
-#undef EXPANDED_SBINDIR
+#undef EXPANDED_GDMCONFIGDIR
 #undef EXPANDED_LIBEXECDIR
 #undef EXPANDED_LIBDIR
-#undef EXPANDED_GDMCONFIGDIR
 #undef EXPANDED_LOCALEDIR
-#undef EXPANDED_AUTHDIR
 #undef EXPANDED_LOGDIR
+#undef EXPANDED_PIXMAPDIR
+#undef EXPANDED_SBINDIR
 #undef EXPANDED_SYSCONFDIR
 #undef EXPANDED_SESSDIR
 #undef X_PATH
@@ -37,16 +53,4 @@
 #undef X_SERVER_PATH
 #undef X_XNEST_PATH
 #undef X_XNEST_CONFIG_OPTIONS
-#undef X_CONF_PATH
 #undef X_CONFIG_OPTIONS
-#undef GETTEXT_PACKAGE
-#undef HAVE_LOGINCAP
-#undef HAVE_SYS_SOCKIO_H
-#undef HAVE_SCHED_YIELD
-#undef ENABLE_IPV6
-#undef HAVE_SELINUX
-#undef HAVE_PASSWDEXPIRED
-#undef HAVE_CHPASS
-#undef HAVE_LOGINRESTRICTIONS
-#undef HAVE_LOGINDEVPERM
-#undef HAVE_ADT
