@@ -57,6 +57,7 @@ gdm_greeter_user_alloc (const gchar *logname, uid_t uid, const gchar *homedir,
 	gchar buf[PIPE_SIZE];
 	size_t size;
 	int bufsize;
+	char *p;
 
 	user = g_new0 (GdmGreeterUser, 1);
 
@@ -66,6 +67,18 @@ gdm_greeter_user_alloc (const gchar *logname, uid_t uid, const gchar *homedir,
 		user->gecos = ve_locale_to_utf8 (gecos);
 	else
 		user->gecos = g_strdup (gecos);
+
+	/* Cut up to first comma since those are ugly arguments and
+	 * not the name anymore, but only if more then 1 comma is found,
+	 * since otherwise it might be part of the actual comment,
+	 * this is sort of "heurestic" because there seems to be no
+	 * real standard, it's all optional */
+	p = strchr (user->gecos, ',');
+	if (p != NULL) {
+		if (strchr (p+1, ',') != NULL)
+			*p = '\0';
+	}
+
 	user->homedir = g_strdup (homedir);
 	if (defface != NULL)
 		user->picture = (GdkPixbuf *)g_object_ref (G_OBJECT (defface));
@@ -260,7 +273,34 @@ gdm_greeter_users_init (void)
     time_t time_started;
 
     if (access (GdmDefaultFace, R_OK) == 0) {
-	    defface = gdk_pixbuf_new_from_file (GdmDefaultFace, NULL);
+		GdkPixbuf *img;
+		guint w, h;
+	
+        img = gdk_pixbuf_new_from_file (GdmDefaultFace, NULL);
+
+		w = gdk_pixbuf_get_width (img);
+		h = gdk_pixbuf_get_height (img);
+
+		if (w > h && w > GdmIconMaxWidth) {
+			h = h * ((gfloat) GdmIconMaxWidth/w);
+			w = GdmIconMaxWidth;
+		} else if (h > GdmIconMaxHeight) {
+			w = w * ((gfloat) GdmIconMaxHeight/h);
+			h = GdmIconMaxHeight;
+		}
+
+		maxwidth = MAX (maxwidth, w);
+		maxheight = MAX (maxheight, h);
+
+		if (w != gdk_pixbuf_get_width (img) ||
+		    h != gdk_pixbuf_get_height (img)) {
+			defface = gdk_pixbuf_scale_simple
+				(img, w, h, GDK_INTERP_BILINEAR);
+			g_object_unref (G_OBJECT (img));
+
+		} else {
+			defface = img;
+		}
     } else  {
 	    syslog (LOG_WARNING,
 		    _("Can't open DefaultImage: %s!"),
@@ -295,7 +335,7 @@ gdm_greeter_users_init (void)
 	    user = gdm_greeter_user_alloc (pwent->pw_name,
 					   pwent->pw_uid,
 					   pwent->pw_dir,
-					   pwent->pw_gecos);
+					   ve_sure_string (pwent->pw_gecos));
 
 	    if ((user) && (! g_list_find_custom (users, user,
 				(GCompareFunc) gdm_greeter_sort_func))) {
